@@ -1,21 +1,22 @@
-# $Id: Node.pm,v 1.8 2007/06/28 18:44:53 ask Exp $
+# $Id: Node.pm,v 1.9 2007/07/13 00:00:15 ask Exp $
 # $Source: /opt/CVS/Getopt-LL/lib/Getopt/LL/DLList/Node.pm,v $
 # $Author: ask $
 # $HeadURL$
-# $Revision: 1.8 $
-# $Date: 2007/06/28 18:44:53 $
+# $Revision: 1.9 $
+# $Date: 2007/07/13 00:00:15 $
 package Getopt::LL::DLList::Node;
 use strict;
 use warnings;
 use Carp;
 use Scalar::Util qw( weaken );
-use version; our $VERSION = qv('0.0.4');
+use version; our $VERSION = qv('0.0.5');
+use 5.006_001;
 {
 
     use vars qw($ALLOCATED_TOTAL);
     $ALLOCATED_TOTAL = 0;
 
-    use Class::Dot qw( :std );
+    use Class::Dot qw( property isa_Object isa_Data );
     property    prev => isa_Object('Getopt::LL::DLList::Node');
     property    next => isa_Object('Getopt::LL::DLList::Node');
     property    data => isa_Data;
@@ -210,7 +211,7 @@ YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
 
 IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY
 COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE
-SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE TO YOU FOR DAMAGES,
+SOFTWARE AS PERMITTED BY THE ABOVE LICENSE, BE LIABLE TO YOU FOR DAMAGES,
 INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING
 OUT OF THE USE OR INABILITY TO USE THE SOFTWARE (INCLUDING BUT NOT LIMITED TO
 LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR
@@ -220,6 +221,10 @@ POSSIBILITY OF SUCH DAMAGES.
 
 =end wikidoc
 
-# Local variables:
-# vim: ts=4
 
+# Local Variables:
+#   mode: cperl
+#   cperl-indent-level: 4
+#   fill-column: 78
+# End:
+# vim: expandtab tabstop=4 shiftwidth=4 shiftround
